// ============================================================================
//
// Copyright (c) 2010, heig-vd.ch, niceideas.ch - Jerome Kehrli
//
// You may distribute this code under the terms of the GNU LGPL license
// (http://www.gnu.org/licenses/lgpl.html). [^]
//
// ============================================================================

package ch.niceideas.communityBoard.data;

import java.io.Serializable;
import javax.persistence.*;
import java.util.List;


/**
 * The persistent class for the CB_FORUM database table.
 * <p />
 * 
 * A forum entity instance represents a forum as it is stored in the database.
 * A forum doesn't belong to any user specifically. A forum holds a collection
 * of notes. 
 */
@Entity
@Table(name="APP.CB_FORUM")
public class Forum implements Serializable {
	
	private static final long serialVersionUID = 1L;
	private int id;
	private String description;
	private String name;
	private List<Note> notes;

    public Forum() {
    }


	@Id
	@GeneratedValue(strategy=GenerationType.IDENTITY)
	@Column(unique=true, nullable=false)
	public int getId() {
		return this.id;
	}

	public void setId(int id) {
		this.id = id;
	}


	@Column(length=1024)
	public String getDescription() {
		return this.description;
	}

	public void setDescription(String description) {
		this.description = description;
	}


	@Column(nullable=false, length=48)
	public String getName() {
		return this.name;
	}

	public void setName(String name) {
		this.name = name;
	}


	//bi-directional many-to-one association to Message
	@OneToMany(mappedBy="forum", cascade={CascadeType.MERGE,CascadeType.PERSIST,CascadeType.REFRESH,CascadeType.REMOVE})
	public List<Note> getNotes() {
		return this.notes;
	}

	public void setNotes(List<Note> notes) {
		this.notes = notes;
	}

	/**
	 * TODO Document me
	 * 
	 * @param note
	 */
    public void addNote(Note note) {
        getNotes().add(note);
    }

    public void refreshNote(Note note) {        
        for (int i = 0; i < getNotes().size(); i++) {
            Note cur = getNotes().get(i);
            if (cur.getId() == note.getId()) {
                getNotes().set(i, note);
                break;
            }
        }
    }
	
}