// ============================================================================
//
// Copyright (c) 2010, heig-vd.ch, niceideas.ch - Jerome Kehrli
//
// You may distribute this code under the terms of the GNU LGPL license
// (http://www.gnu.org/licenses/lgpl.html). [^]
//
// ============================================================================


package ch.niceideas.communityBoard.data;

import java.io.Serializable;
import java.sql.Timestamp;

import javax.persistence.*;


/**
 * The persistent class for the CB_RATING database table.
 * 
 */
@Entity
@Table(name="APP.CB_RATING")
public class Rating implements Serializable {
	
	private static final long serialVersionUID = 1L;
	private int id;
	private Timestamp rated = new Timestamp(System.currentTimeMillis());
	private String comment;
	private int rating;
	private Note note;
	private User user;

    public Rating() {
    }

    /**
     * We use the preRemove hook to unregister the rating from the list of 
     * ratings attached to the note and the list of ratings from the user.
     */
    @PreRemove
    public void preRemove() {
        getNote().getRatings().remove(this);        
        getUser().getRatings().remove(this);
    }

	@Id
	@GeneratedValue(strategy=GenerationType.IDENTITY)
	@Column(unique=true, nullable=false)
	public int getId() {
		return this.id;
	}

	public void setId(int id) {
		this.id = id;
	}


	@Column(length=1)
	public String getComment() {
		return this.comment;
	}

	public void setComment(String comment) {
		this.comment = comment;
	}


	@Column(name="RATING")
	public int getRating() {
		return this.rating;
	}

	public void setRating(int rating) {
		this.rating = rating;
	}
	
	@Column(nullable=false)
	public Timestamp getRated() {
		return this.rated;
	}

	public void setRated(Timestamp rated) {
		this.rated = rated;
	}


	//bi-directional many-to-one association to Message
	@ManyToOne(fetch=FetchType.LAZY)
	@JoinColumn(name="NOTE_ID", nullable=false)
	public Note getNote() {
		return this.note;
	}

	public void setNote(Note note) {
		this.note = note;
		if (note != null) {
		    note.refreshRating(this);
		}
	}
	
	//bi-directional many-to-one association to User
	@ManyToOne(fetch=FetchType.LAZY)
	@JoinColumn(name="USER_ID", nullable=false)
	public User getUser() {
		return this.user;
	}

	public void setUser(User user) {
		this.user = user;
		if (user != null) {
            user.addRating (this);
        }
	}
	
	
}