// ============================================================================
//
// Copyright (c) 2010, heig-vd.ch, niceideas.ch - Jerome Kehrli
//
// You may distribute this code under the terms of the GNU LGPL license
// (http://www.gnu.org/licenses/lgpl.html). [^]
//
// ============================================================================


package ch.niceideas.communityBoard.data;

import java.io.Serializable;
import javax.persistence.*;
import java.util.List;


/**
 * The persistent class for the CB_USER database table.
 * <p />
 * 
 * The User entity represents a user of the CommunityBoard application as it
 * is stored in database. As of now a user is identified by his nickname and
 * authenticated with his password. We also record users email as an additional 
 * information.
 */
@Entity
@Table(name="APP.CB_USER")
public class User implements Serializable {
	
	private static final long serialVersionUID = 1L;
	private int id;
	private String email;
	private String nickname;
	private String password;
	private List<Note> notes;
	private List<Rating> ratings;

    public User() {
    }


	@Id
	@GeneratedValue(strategy=GenerationType.IDENTITY)
	@Column(unique=true, nullable=false)
	public int getId() {
		return this.id;
	}

	public void setId(int id) {
		this.id = id;
	}


	@Column(nullable=false, length=128)
	public String getEmail() {
		return this.email;
	}

	public void setEmail(String email) {
		this.email = email;
	}


	@Column(nullable=false, length=48)
	public String getNickname() {
		return this.nickname;
	}

	public void setNickname(String nickname) {
		this.nickname = nickname;
	}


	@Column(nullable=false, length=48)
	public String getPassword() {
		return this.password;
	}

	public void setPassword(String password) {
		this.password = password;
	}

	//bi-directional many-to-one association to Note
	@OneToMany(mappedBy="user")
	public List<Note> getNotes() {
		return this.notes;
	}

	public void setNotes(List<Note> notes) {
		this.notes = notes;
	}

	//bi-directional many-to-one association to Rating
	@OneToMany(mappedBy="user")
	public List<Rating> getRatings() {
		return this.ratings;
	}

	public void setRatings(List<Rating> ratings) {
		this.ratings = ratings;
	}
	
	public void addNote(Note note) {
	    this.getNotes().add(note);
	}
	
	public void addRating(Rating rating) {
        this.getRatings().add(rating);
    }

    public void refreshNote(Note note) {
        for (int i = 0; i < getNotes().size(); i++) {
            Note cur = getNotes().get(i);
            if (cur.getId() == note.getId()) {
                getNotes().set(i, note);
                break;
            }
        }
    }
}