// ============================================================================
//
// Copyright (c) 2010, heig-vd.ch, niceideas.ch - Jerome Kehrli
//
// You may distribute this code under the terms of the GNU LGPL license
// (http://www.gnu.org/licenses/lgpl.html). [^]
//
// ============================================================================


package ch.niceideas.communityBoard.web;

import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;



/**
 * Servlet implementation class Controller.
 * <p />
 * 
 * This implements a rather short and simple yet effective front controller 
 * taking car of the dispatching of the HTTP requests to the JSP implementing
 * the action or view asked by the user.
 */
public class Controller extends HttpServlet {
	
	private static final long serialVersionUID = 1L;
	
	private static final Logger logger = Logger.getLogger(Controller.class.getName());
	
	public static final String WEB_INF_PREFIX = "/WEB-INF/";
	public static final String SESSION_KEY_USER = "LOGGED_IN_USER";
	
	private static final Pattern ACTION_PATTERN = Pattern.compile("(.*\\/)(.*)"); 
       
    /**
     * @see HttpServlet#HttpServlet()
     */
    public Controller() {
        super();
        // TODO Auto-generated constructor stub
    }

	/**
	 * @see HttpServlet#doGet(HttpServletRequest request, HttpServletResponse response)
	 */
    @Override
	protected void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
		processRequest (request, response);
	}	

	/**
	 * @see HttpServlet#doPost(HttpServletRequest request, HttpServletResponse response)
	 */
	@Override
	protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
		processRequest (request, response);
	}

	/**
	 * This is the big deal. Here is where the request is analyzed and where the 
	 * dispatching to the corresponding JSP takes place.
	 * 
	 * @param request
	 * @param response
	 */
	private void processRequest(HttpServletRequest request, HttpServletResponse response) {
		try {
			// if the user is not logged in yet, forard it to the login JSP
			
			String targetJSP = null;
			Matcher actionMatcher = ACTION_PATTERN.matcher(request.getRequestURL());
			if (!actionMatcher.matches()) {
				logger.severe ("No action found after '/controller/' in the request URL");
				response.sendError(404, "No action found after '/controller/' in the request URL");
				return;
			}
			String actionPart = actionMatcher.group(2);
			if (!actionPart.endsWith(".do")) {
				logger.severe ("Action doesn't end with '.do'");
				response.sendError(404, "Action doesn't end with '.do'");
				return;
			}
			targetJSP = WEB_INF_PREFIX + actionPart.substring(0, actionPart.length() - ".do".length()) + ".jsp";
			logger.info ("target JSP : " + targetJSP);			

	        getServletConfig().getServletContext().getRequestDispatcher(targetJSP).forward(request,response);

	    } catch (ServletException e) {
	        logger.log(Level.SEVERE, e.getMessage(), e);
	        try {
				response.sendError(501, "Internal server error " + e.getMessage());
			} catch (IOException e1) {
				logger.log(Level.SEVERE, e.getMessage(), e);
				// ignored
			}
	      
	    } catch (IOException e) {
	    	logger.log(Level.SEVERE, e.getMessage(), e);
	    	try {
				response.sendError(501, "Internal server error " + e.getMessage());
			} catch (IOException e1) {
				logger.log(Level.SEVERE, e.getMessage(), e);
				// ignored
			}
	    }
	}

}
