// ============================================================================
//
// Copyright (c) 2010, heig-vd.ch, niceideas.ch - Jerome Kehrli
//
// You may distribute this code under the terms of the GNU LGPL license
// (http://www.gnu.org/licenses/lgpl.html). [^]
//
// ============================================================================


package ch.niceideas.communityBoard.web;

import java.util.logging.Level;
import java.util.logging.Logger;

import javax.servlet.http.HttpServletRequest;

import ch.niceideas.communityBoard.data.Forum;
import ch.niceideas.communityBoard.data.Note;
import ch.niceideas.communityBoard.data.User;
import ch.niceideas.communityBoard.service.ForumException;
import ch.niceideas.communityBoard.service.ForumService;

/**
 * This is nothing more that a helper class associated to the 
 * <code>noteEdition.jsp</code>. It provides the JSP with the routine required 
 * to perform the actions triggered by the user through the JSP. 
 */
public class NoteEditionHelper {
    
    private static final Logger logger = Logger.getLogger(NoteEditionHelper.class.getName());
    
    /**
     * Perform the desired action. The type of action is either add, update or 
     * delete. <br />
     * The action is applied on the note identified through the ID given as
     * a request parameter (except for the 'add' action of course).
     *  
     * @param request the HttpServletRequest from the JSP call.
     * @return a string giving the JSP the page title to be used. This is a trick 
     *         enabling the JSP to change its title according to teh desired action.
     */
    public static String performAction (HttpServletRequest request) {
        
        ForumService forumService = ServiceLocator.lookupBean(ForumService.class, "java:global/CommunityBoard/CommunityBoard_services/ForumService");
        
        String action = request.getParameter("action");
        String title = null;
        String noteIdAsString = request.getParameter("noteId");
        Note note = null;
        if (action == null) {
            action = "add";
        }        

        if (action.equals("add")) {
            title = "Add new note ...";
            request.setAttribute("forumId", request.getParameter("forumId"));
        } 

        if (action.equals("edit") || action.equals("delete")) {
            if (noteIdAsString != null) {
                int noteId = Integer.parseInt(noteIdAsString);
                try {
                    note = forumService.readNote(noteId);
                } catch (ForumException e) {
                    logger.log(Level.SEVERE, e.getMessage(), e);
                    // TODO
                    throw new IllegalStateException();
                }
            }
            request.setAttribute("note", note);
            request.setAttribute("forumId", note.getForum().getId());
            if (action.equals("edit")) {
                title = "Edit Note '" + note.getTitle() + "'";
            } else if (action.equals("delete")) {
                title = "Delete note '" + note.getTitle() + "'";
            }
        }
        
        request.setAttribute("action", action);
        request.setAttribute("title", title);
        
        // Now I have everything. So what should I do ?
        String confirm = request.getParameter("confirm");
        if (confirm != null && confirm.equals("true")) {
            
            try {
            
                if (action.equals("add")) {
                    
                    String noteTitle = request.getParameter("title");
                    String noteContent = request.getParameter("content");
                    String forumIdAsString = request.getParameter("forumId");
                    String userIdAsString = request.getParameter("userId");
                    
                    request.setAttribute("forumId", forumIdAsString);
                    
                    Forum forum = null;
                    if (forumIdAsString != null) {
                        int forumId = Integer.parseInt(forumIdAsString);
                        try {
                            forum = forumService.readForum(forumId);
                        } catch (ForumException e) {
                            logger.log(Level.SEVERE, e.getMessage(), e);
                            // TODO
                            throw new IllegalStateException();
                        }
                    }
                    if (forum == null) {
                        // TODO
                        throw new IllegalStateException();
                    }
                    
                    User user = null;
                    if (userIdAsString != null) {
                        int userId = Integer.parseInt(userIdAsString);
                        try {
                            user = forumService.readUser(userId);
                        } catch (ForumException e) {
                            logger.log(Level.SEVERE, e.getMessage(), e);
                            // TODO
                            throw new IllegalStateException();
                        }
                    }
                    if (user == null) {
                        // TODO
                        throw new IllegalStateException();
                    }
                    
                    Note newNote = new Note();
                    newNote.setTitle(noteTitle);
                    newNote.setContent (noteContent);
                    newNote.setForum(forum);
                    newNote.setUser(user);
                    
                    forumService.createNote (newNote);
                    
                } else if (action.equals("edit")) {
                    
                    String noteTitle = request.getParameter("title");
                    String noteContent = request.getParameter("content");
                    
                    request.setAttribute("forumId", note.getForum().getId());
                    
                    note.setTitle(noteTitle);
                    note.setContent (noteContent);
                    
                    forumService.updateNote (note);
                    
                } else if (action.equals("delete")) {
                    
                    request.setAttribute("forumId", note.getForum().getId());
                    
                    forumService.deleteNote (note);
                }
                
                request.setAttribute("done", "true");
                
            } catch (ForumException e) {
                logger.log(Level.SEVERE, e.getMessage(), e);
                // TODO
                throw new IllegalStateException(e);
            }
            
        }
        
        return action;
    }

}
