// ============================================================================
//
// Copyright (c) 2010, heig-vd.ch, niceideas.ch - Jerome Kehrli
//
// You may distribute this code under the terms of the GNU LGPL license
// (http://www.gnu.org/licenses/lgpl.html). [^]
//
// ============================================================================


package ch.niceideas.communityBoard.web;

import java.util.logging.Level;
import java.util.logging.Logger;

import javax.servlet.http.HttpServletRequest;

import ch.niceideas.communityBoard.data.Note;
import ch.niceideas.communityBoard.data.Rating;
import ch.niceideas.communityBoard.data.User;
import ch.niceideas.communityBoard.service.ForumException;
import ch.niceideas.communityBoard.service.ForumService;

/**
 * This is nothing more that a helper class associated to the 
 * <code>ratingEdition.jsp</code>. It provides the JSP with the routine required 
 * to perform the actions triggered by the user through the JSP. 
 */
public class RatingEditionHelper {
    
    private static final Logger logger = Logger.getLogger(RatingEditionHelper.class.getName());
    
    /**
     * Perform the desired action. The type of action is either add, update or 
     * delete. <br />
     * The action is applied on the rating identified through the ID given as
     * a request parameter (except for the 'add' action of course).
     *  
     * @param request the HttpServletRequest from the JSP call.
     * @return a string giving the JSP the page title to be used. This is a trick 
     *         enabling the JSP to change its title according to teh desired action.
     */
    public static String performAction (HttpServletRequest request) {
        
        ForumService forumService = ServiceLocator.lookupBean(ForumService.class, "java:global/CommunityBoard/CommunityBoard_services/ForumService");
        
        String action = request.getParameter("action");
        String title = null;
        String ratingIdAsString = request.getParameter("ratingId");
        Rating rating = null;
        if (action == null) {
            action = "add";
        }        

        if (action.equals("add")) {
            title = "Add new rating ...";
            request.setAttribute("noteId", request.getParameter("noteId"));
        } 

        if (action.equals("edit") || action.equals("delete")) {
            if (ratingIdAsString != null) {
                int ratingId = Integer.parseInt(ratingIdAsString);
                try {
                    rating = forumService.readRating(ratingId);
                } catch (ForumException e) {
                    logger.log(Level.SEVERE, e.getMessage(), e);
                    // TODO
                    throw new IllegalStateException();
                }
            }
            request.setAttribute("rating", rating);
            request.setAttribute("noteId", rating.getNote().getId());
            if (action.equals("edit")) {
                title = "Edit Rating from '" + rating.getUser().getNickname() + "' with value '" + rating.getRating() + "'";
            } else if (action.equals("delete")) {
                title = "Delete Rating from '" + rating.getUser().getNickname() + "' with value '" + rating.getRating() + "'";
            }
        }
        
        request.setAttribute("action", action);
        request.setAttribute("title", title);
        
        // Now I have everything. So what should I do ?
        String confirm = request.getParameter("confirm");
        if (confirm != null && confirm.equals("true")) {
            
            try {
            
                if (action.equals("add")) {
                    
                    String ratingValueAsString = request.getParameter("rating");
                    int ratingValue = 0;
                    if (ratingValueAsString != null) {
                        ratingValue = Integer.parseInt(ratingValueAsString);
                    }                    
                    
                    String ratingComment = request.getParameter("comment");
                    String noteIdAsString = request.getParameter("noteId");
                    String userIdAsString = request.getParameter("userId");
                    
                    request.setAttribute("noteId", noteIdAsString);
                    
                    Note note = null;
                    if (noteIdAsString != null) {
                        int noteId = Integer.parseInt(noteIdAsString);
                        try {
                            note = forumService.readNote(noteId);
                        } catch (ForumException e) {
                            logger.log(Level.SEVERE, e.getMessage(), e);
                            // TODO
                            throw new IllegalStateException();
                        }
                    }
                    if (note == null) {
                        // TODO
                        throw new IllegalStateException();
                    }
                    
                    User user = null;
                    if (userIdAsString != null) {
                        int userId = Integer.parseInt(userIdAsString);
                        try {
                            user = forumService.readUser(userId);
                        } catch (ForumException e) {
                            logger.log(Level.SEVERE, e.getMessage(), e);
                            // TODO
                            throw new IllegalStateException();
                        }
                    }
                    if (user == null) {
                        // TODO
                        throw new IllegalStateException();
                    }
                    
                    Rating newRating = new Rating();
                    newRating.setRating(ratingValue);
                    newRating.setComment(ratingComment);
                    newRating.setNote(note);
                    newRating.setUser(user);
                    
                    forumService.createRating (newRating);
                    
                } else if (action.equals("edit")) {
                    
                    String ratingValueAsString = request.getParameter("rating");
                    int ratingValue = 0;
                    if (ratingValueAsString != null) {
                        ratingValue = Integer.parseInt(ratingValueAsString);
                    }                    
                    
                    String ratingComment = request.getParameter("comment");
                    
                    request.setAttribute("noteId", rating.getNote().getId());
                    
                    rating.setRating(ratingValue);
                    rating.setComment (ratingComment);
                    
                    forumService.updateRating (rating);
                    
                } else if (action.equals("delete")) {
                    
                    request.setAttribute("noteId", rating.getNote().getId());
                    
                    forumService.deleteRating (rating);
                }
                
                request.setAttribute("done", "true");
                
            } catch (ForumException e) {
                logger.log(Level.SEVERE, e.getMessage(), e);
                // TODO
                throw new IllegalStateException();
            }
            
        }
        
        return action;
    }

}
