// ============================================================================
//
// Copyright (c) 2010, heig-vd.ch, niceideas.ch - Jerome Kehrli
//
// You may distribute this code under the terms of the GNU LGPL license
// (http://www.gnu.org/licenses/lgpl.html). [^]
//
// ============================================================================


package ch.niceideas.communityBoard.web;

import java.util.logging.Level;
import java.util.logging.Logger;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;

/**
 * The CommunityBoard web application splits its various classes across packages 
 * matching the involved layers. As such, the presentation layer where the 
 * controller and the JSP files are located ends up packaged in a WAR file while
 * the services (EJBs) and Entities end up in different jar files. 
 * <p />
 * 
 * This causes an issue to the usual JEE containers as the EJB annotations are 
 * not processed on projects not containing any EJB (or an ejb-jar.xml 
 * deployment descriptor). This is the case of the WAR file containing the 
 * controller servlet and the JPS. Thus, the services annotated with the @EJB 
 * annotation are not properly injected upon application startup.
 * <p />
 * 
 * So another system is required in order to enable the JSP to get a reference
 * on the business services such as the EJBs. This system usually involves a 
 * lookup for the desired services in the JNDI tree. And this is where the 
 * <i>ServiceLocator</i> kicks in. <br />
 * Its whole purpose is to make this JNDI lookup a bit more straightforward.   
 */
public class ServiceLocator {
	
	private static final Logger logger = Logger.getLogger(ServiceLocator.class.getName());
	
    @SuppressWarnings("unchecked")
	public static <T> T lookupBean(Class<T> ifClass, String jndiName) {
        try {
            Context c = new InitialContext();
            return (T) c.lookup(jndiName);
        } catch(NamingException e) {
        	logger.log(Level.SEVERE, e.getMessage(), e);
        }
        return null;
    }
}
