// ============================================================================
//
// Copyright (c) 2010, heig-vd.ch, niceideas.ch - Jerome Kehrli
//
// You may distribute this code under the terms of the GNU LGPL license
// (http://www.gnu.org/licenses/lgpl.html). [^]
//
// ============================================================================


package ch.niceideas.communityBoard.web;

import java.util.logging.Level;
import java.util.logging.Logger;

import javax.servlet.http.HttpServletRequest;

import ch.niceideas.communityBoard.data.User;
import ch.niceideas.communityBoard.service.ForumException;
import ch.niceideas.communityBoard.service.ForumService;

/**
 * This is nothing more that a helper class associated to the 
 * <code>userEdition.jsp</code>. It provides the JSP with the routine required 
 * to perform the actions triggered by the user through the JSP. 
 */
public class UserEditionHelper {
    
    private static final Logger logger = Logger.getLogger(UserEditionHelper.class.getName());
    
    /**
     * Perform the desired action. The type of action is either add, update or 
     * delete. <br />
     * The action is applied on the user identified through the ID given as
     * a request parameter (except for the 'add' action of course).
     *  
     * @param request the HttpServletRequest from the JSP call.
     * @return a string giving the JSP the page title to be used. This is a trick 
     *         enabling the JSP to change its title according to teh desired action.
     */
    public static String performAction (HttpServletRequest request) {
        
        ForumService forumService = ServiceLocator.lookupBean(ForumService.class, "java:global/CommunityBoard/CommunityBoard_services/ForumService");
        
        String action = request.getParameter("action");
        String title = null;
        String userIdAsString = request.getParameter("userId");
        User user = null;
        if (action == null) {
            action = "add";
        }        

        if (action.equals("add")) {
            title = "Create new user ...";
        } 

        if (action.equals("edit") || action.equals("delete")) {
            if (userIdAsString != null) {
                int userId = Integer.parseInt(userIdAsString);
                try {
                    user = forumService.readUser(userId);
                } catch (ForumException e) {
                    logger.log(Level.SEVERE, e.getMessage(), e);
                    // TODO
                    throw new IllegalStateException();
                }
            }
            request.setAttribute("user", user);
            if (action.equals("edit")) {
                title = "Edit user '" + user.getNickname() + "'";
            } else if (action.equals("delete")) {
                title = "Delete user '" + user.getNickname() + "'";
            }
        }
        
        request.setAttribute("action", action);
        request.setAttribute("title", title);
        
        // Now I have everything. So what should I do ?
        String confirm = request.getParameter("confirm");
        if (confirm != null && confirm.equals("true")) {
            
            try {
            
                if (action.equals("add")) {
                    
                    String userNickname = request.getParameter("nickname");
                    String userEmail = request.getParameter("email");
                    String userPassword = request.getParameter("password");
                    
                    User newUser = new User();
                    newUser.setNickname(userNickname);
                    newUser.setEmail (userEmail);
                    newUser.setPassword (userPassword);
                    
                    forumService.createUser (newUser);
                    
                } else if (action.equals("edit")) {
                    
                    String userNickname = request.getParameter("nickname");
                    String userEmail = request.getParameter("email");
                    String userPassword = request.getParameter("password");
                                
                    user.setNickname(userNickname);
                    user.setEmail (userEmail);
                    user.setPassword (userPassword);
                    
                    forumService.updateUser (user);
                    
                } else if (action.equals("delete")) {

                    if (user.getNotes().size() > 0 || user.getRatings().size() > 0) {
                        throw new IllegalStateException("Unable to delete user as he holds notes or ratings.");
                    }
                    forumService.deleteUser (user);
                }
                
                request.setAttribute("done", "true");
                
            } catch (ForumException e) {
                logger.log(Level.SEVERE, e.getMessage(), e);
                // TODO
                throw new IllegalStateException();
            }
            
        }
        
        return action;
    }

}
