// ============================================================================
//
// Copyright (c) 2010, heig-vd.ch, niceideas.ch - Jerome Kehrli
//
// You may distribute this code under the terms of the GNU LGPL license
// (http://www.gnu.org/licenses/lgpl.html). [^]
//
// ============================================================================


package ch.niceideas.communityBoard.manager;

import java.util.List;

import javax.ejb.Local;

import ch.niceideas.communityBoard.data.Forum;

/**
 * Business Interface for ForumManager. 
 * <p />
 * 
 * At the moment, mostly due to the to the overwhelming simplicity of the 
 * CommunityBoard application, this manager actually behaves much more like a 
 * plain old DAO pattern. As such, it provides the usual CRUD API on the 
 * underlying Entity.  
 * <p />
 * 
 * In this simple application we have no need for any remoting of any kind and 
 * hence we limit all our EJBs to the @Local interface only.
 */
@Local
public interface ForumManager {

    /**
     * List all forums available in the database
     * 
     * @return a list containing every forum
     */
	List<Forum> listForums ();
	
	/**
	 * Read the forum corresponding to the provided ID.
	 * 
	 * @param forumId the ID of the forum to read.
	 * @return the corresponding forum
	 */
	Forum readForum (int forumId);

	/**
	 * Insert the forum given as argument in the database.
	 * 
	 * @param newForum the new forum to insert in DB.
	 */
	void createForum(Forum newForum);

	/**
	 * Delete the forum given as argument from the database.
	 * 
	 * @param forum the forum to be deleted
	 */
    void deleteForum(Forum forum);

    /**
     * Update the forum given as argument in the database. 
     * 
     * @param forum the forum to be updated in DB
     */
    void updateForum(Forum forum);
}
