// ============================================================================
//
// Copyright (c) 2010, heig-vd.ch, niceideas.ch - Jerome Kehrli
//
// You may distribute this code under the terms of the GNU LGPL license
// (http://www.gnu.org/licenses/lgpl.html). [^]
//
// ============================================================================


package ch.niceideas.communityBoard.manager;

import java.util.List;

import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.PersistenceContextType;
import javax.persistence.PersistenceProperty;
import javax.persistence.TypedQuery;
import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;

import ch.niceideas.communityBoard.data.Forum;

/**
 * Stateless Session Bean implementation class ForumManager.
 * <b />
 * 
 * This is the actual EJB implementation. It provides implementations for the 
 * business methods defined in the interface. The implementation is neither 
 * exposed not available to the outside world. Clients are meant to use the EJB
 * interface. In our case, only the @Local interface is provided.
 */
@Stateless(name = "ForumManager")
public class ForumManagerImpl implements ForumManager {
	
	@PersistenceContext(unitName = "CommunityBoard_data",  type=PersistenceContextType.TRANSACTION, properties = {
			@PersistenceProperty(name="javax.persistence.provider", 
					             value="oracle.toplink.essentials.ejb.cmp3.EntityManagerFactoryProvider")
	}) 		
	private EntityManager em;

    /**
     * Default constructor. 
     */
    public ForumManagerImpl() {
    }

    /**
     * {@inheritDoc}}
     */ 
    @Override
    public List<Forum> listForums () {
    	CriteriaBuilder cb = em.getCriteriaBuilder();
    	CriteriaQuery<Forum> cq = cb.createQuery(Forum.class);
    	TypedQuery<Forum> query = em.createQuery(cq);
    	return query.getResultList();

    }
    
    /**
     * {@inheritDoc}}
     */ 
    @Override
    public Forum readForum (int forumId) {
    	return em.find(Forum.class, forumId);
    }

    /**
     * {@inheritDoc}}
     */ 
    @Override
    public void createForum(Forum newForum) {
        em.persist(newForum);
    }

    /**
     * {@inheritDoc}}
     */ 
    @Override
    public void deleteForum(Forum forum) {
        // unfortunately forum might be detached
        em.remove(readForum(forum.getId()));
    }

    /**
     * {@inheritDoc}}
     */ 
    @Override
    public void updateForum(Forum forum) {
        em.merge(forum);
    }
}
