// ============================================================================
//
// Copyright (c) 2010, heig-vd.ch, niceideas.ch - Jerome Kehrli
//
// You may distribute this code under the terms of the GNU LGPL license
// (http://www.gnu.org/licenses/lgpl.html). [^]
//
// ============================================================================


package ch.niceideas.communityBoard.manager;

import java.util.List;

import javax.ejb.Local;

import ch.niceideas.communityBoard.data.Note;

/**
 * Business Interface for ForumManager.
 * <p />
 * 
 * At the moment, mostly due to the to the overwhelming simplicity of the 
 * CommunityBoard application, this manager actually behaves much more like a 
 * plain old DAO pattern. As such, it provides the usual CRUD API on the 
 * underlying Entity.  
 * <p />
 * 
 * In this simple application we have no need for any remoting of any kind and 
 * hence we limit all our EJBs to the @Local interface only.
 */
@Local
public interface NoteManager {

	/**
	 * List all notes belonging to the forum identified by the ID given as
	 * argument
	 * 
	 * @param forumId the ID of the forum whose notes should be retrieved.
	 * @return the corresponding list of notes
	 */
	List<Note> listNotes(int forumId);
	
	/**
     * Read the note corresponding to the provided ID.
     * 
     * @param noteId the ID of the note to read.
     * @return the corresponding note
     */
	Note readNote (int noteId);
	
	/**
     * Insert the note given as argument in the database.
     * 
     * @param newNote the new note to insert in DB.
     */
    void createNote(Note newNote);

    /**
     * Delete the note given as argument from the database.
     * 
     * @param note the note to be deleted
     */
    void deleteNote(Note note);

    /**
     * Update the note given as argument in the database. 
     * 
     * @param note the note to be updated in DB
     */
    void updateNote(Note note);
}
