// ============================================================================
//
// Copyright (c) 2010, heig-vd.ch, niceideas.ch - Jerome Kehrli
//
// You may distribute this code under the terms of the GNU LGPL license
// (http://www.gnu.org/licenses/lgpl.html). [^]
//
// ============================================================================


package ch.niceideas.communityBoard.manager;

import java.util.List;

import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.PersistenceContextType;
import javax.persistence.PersistenceProperty;
import javax.persistence.TypedQuery;
import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;

import ch.niceideas.communityBoard.data.Note;

/**
 * Stateless Session Bean implementation class NoteManager.
 * <b />
 * 
 * This is the actual EJB implementation. It provides implementations for the 
 * business methods defined in the interface. The implementation is neither 
 * exposed not available to the outside world. Clients are meant to use the EJB
 * interface. In our case, only the @Local interface is provided.
 */
@Stateless(name = "NoteManager")
public class NoteManagerImpl implements NoteManager {
	
	@PersistenceContext(unitName = "CommunityBoard_data",  type=PersistenceContextType.TRANSACTION, properties = {
			@PersistenceProperty(name="javax.persistence.provider", 
					             value="oracle.toplink.essentials.ejb.cmp3.EntityManagerFactoryProvider")
	}) 		
	private EntityManager em;

    /**
     * Default constructor. 
     */
    public NoteManagerImpl() {
    }

    /**
     * {@inheritDoc}}
     */
    @Override
    public List<Note> listNotes(int forumId) {
    	CriteriaBuilder cb = em.getCriteriaBuilder();
    	CriteriaQuery<Note> cq = cb.createQuery(Note.class);
    	Root<Note> rt = cq.from(Note.class);
    	cq.where(cb.equal(rt.get("forum").get("id"),forumId));
    	TypedQuery<Note> query = em.createQuery(cq);
    	return query.getResultList();
    }
    
    /**
     * {@inheritDoc}}
     */
    @Override
	public Note readNote (int noteId) {
    	return em.find(Note.class, noteId);
	}

    /**
     * {@inheritDoc}}
     */ 
    @Override
    public void createNote(Note newNote) {
        em.persist(newNote);

    }

    /**
     * {@inheritDoc}}
     */ 
    @Override
    public void deleteNote(Note note) {
        // unfortunately note might be detached
        em.remove(readNote(note.getId()));
    }

    /**
     * {@inheritDoc}}
     */ 
    @Override
    public void updateNote(Note note) {
        em.merge(note);
    }
}
