// ============================================================================
//
// Copyright (c) 2010, heig-vd.ch, niceideas.ch - Jerome Kehrli
//
// You may distribute this code under the terms of the GNU LGPL license
// (http://www.gnu.org/licenses/lgpl.html). [^]
//
// ============================================================================


package ch.niceideas.communityBoard.manager;

import java.util.List;

import javax.ejb.Local;

import ch.niceideas.communityBoard.data.Rating;

/**
 * Business Interface for ForumManager.
 * <p />
 * 
 * At the moment, mostly due to the to the overwhelming simplicity of the 
 * CommunityBoard application, this manager actually behaves much more like a 
 * plain old DAO pattern. As such, it provides the usual CRUD API on the 
 * underlying Entity.  
 * <p />
 * 
 * In this simple application we have no need for any remoting of any kind and 
 * hence we limit all our EJBs to the @Local interface only.
 */
@Local
public interface RatingManager {

    /**
     * List all ratings belonging to the note identified by the ID given as
     * argument
     * 
     * @param noteId the ID of the note whose ratings should be retrieved.
     * @return the corresponding list of ratings
     */
	List<Rating> listRatings(int noteId);
	
	/**
     * Read the rating corresponding to the provided ID.
     * 
     * @param ratingId the ID of the rating to read.
     * @return the corresponding rating
     */
	Rating readRating (int ratingId);
	
	/**
     * Insert the rating given as argument in the database.
     * 
     * @param newRating the new rating to insert in DB.
     */
    void createRating(Rating newRating);

    /**
     * Delete the rating given as argument from the database.
     * 
     * @param rating the rating to be deleted
     */
    void deleteRating(Rating rating);

    /**
     * Update the rating given as argument in the database. 
     * 
     * @param rating the rating to be updated in DB
     */
    void updateRating(Rating rating);
}
