// ============================================================================
//
// Copyright (c) 2010, heig-vd.ch, niceideas.ch - Jerome Kehrli
//
// You may distribute this code under the terms of the GNU LGPL license
// (http://www.gnu.org/licenses/lgpl.html). [^]
//
// ============================================================================


package ch.niceideas.communityBoard.manager;

import java.util.List;

import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.PersistenceContextType;
import javax.persistence.PersistenceProperty;
import javax.persistence.TypedQuery;
import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;

import ch.niceideas.communityBoard.data.Rating;

/**
 * Stateless Session Bean implementation class RatingManager.
 * <b />
 * 
 * This is the actual EJB implementation. It provides implementations for the 
 * business methods defined in the interface. The implementation is neither 
 * exposed not available to the outside world. Clients are meant to use the EJB
 * interface. In our case, only the @Local interface is provided.
 */
@Stateless(name = "RatingManager")
public class RatingManagerImpl implements RatingManager {
	
	@PersistenceContext(unitName = "CommunityBoard_data",  type=PersistenceContextType.TRANSACTION, properties = {
			@PersistenceProperty(name="javax.persistence.provider", 
					             value="oracle.toplink.essentials.ejb.cmp3.EntityManagerFactoryProvider")
	}) 		
	private EntityManager em;

    /**
     * Default constructor. 
     */
    public RatingManagerImpl() {
    }

    /**
     * {@inheritDoc}}
     */
    @Override
    public List<Rating> listRatings(int noteId) {
    	CriteriaBuilder cb = em.getCriteriaBuilder();
    	CriteriaQuery<Rating> cq = cb.createQuery(Rating.class);
    	Root<Rating> rt = cq.from(Rating.class);
    	cq.where(cb.equal(rt.get("note").get("id"),noteId));
    	TypedQuery<Rating> query = em.createQuery(cq);
    	return query.getResultList();
    }
    
    /**
     * {@inheritDoc}}
     */
    @Override
	public Rating readRating (int ratingId) {
    	return em.find(Rating.class, ratingId);
	}

    /**
     * {@inheritDoc}}
     */ 
    @Override
    public void createRating(Rating newRating) {
        em.persist(newRating);
    }

    /**
     * {@inheritDoc}}
     */ 
    @Override
    public void deleteRating(Rating rating) {
        // unfortunately rating might be detached
        em.remove(readRating(rating.getId()));
    }

    /**
     * {@inheritDoc}}
     */ 
    @Override
    public void updateRating(Rating rating) {
        em.merge(rating);       
    }
}
