// ============================================================================
//
// Copyright (c) 2010, heig-vd.ch, niceideas.ch - Jerome Kehrli
//
// You may distribute this code under the terms of the GNU LGPL license
// (http://www.gnu.org/licenses/lgpl.html). [^]
//
// ============================================================================


package ch.niceideas.communityBoard.manager;

import java.util.List;

import javax.ejb.Local;

import ch.niceideas.communityBoard.data.User;

/**
 * Business Interface for UserManager.
 * <p />
 * 
 * At the moment, mostly due to the to the overwhelming simplicity of the 
 * CommunityBoard application, this manager actually behaves much more like a 
 * plain old DAO pattern. As such, it provides the usual CRUD API on the 
 * underlying Entity.  
 * <p />
 * 
 * In this simple application we have no need for any remoting of any kind and 
 * hence we limit all our EJBs to the @Local interface only.
 */
@Local
public interface UserManager {

    /**
     * TODO Document me 
     * 
     * @param nickname
     * @return
     */
    User findUser (String nickname);
    
    /**
     * Read the user corresponding to the provided ID.
     * 
     * @param userId the ID of the user to read.
     * @return the corresponding user
     */
    User readUser (int userId);
    
    /**
     * List all users available in the database
     * 
     * @return a list containing every user
     */  
    List<User> listUsers ();
    
    /**
     * Insert the user given as argument in the database.
     * 
     * @param newUser the new user to insert in DB.
     */
    void createUser(User newUser);

    /**
     * Delete the user given as argument from the database.
     * 
     * @param user the user to be deleted
     */
    void deleteUser(User user);

    /**
     * Update the user given as argument in the database. 
     * 
     * @param user the user to be updated in DB
     */
    void updateUser(User user);
}
