// ============================================================================
//
// Copyright (c) 2010, heig-vd.ch, niceideas.ch - Jerome Kehrli
//
// You may distribute this code under the terms of the GNU LGPL license
// (http://www.gnu.org/licenses/lgpl.html). [^]
//
// ============================================================================


package ch.niceideas.communityBoard.manager;

import java.util.List;

import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.PersistenceContextType;
import javax.persistence.PersistenceProperty;
import javax.persistence.TypedQuery;
import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;

import ch.niceideas.communityBoard.data.User;

/**
 * Stateless Session Bean implementation class UserManager.
 * <b />
 * 
 * This is the actual EJB implementation. It provides implementations for the 
 * business methods defined in the interface. The implementation is neither 
 * exposed not available to the outside world. Clients are meant to use the EJB
 * interface. In our case, only the @Local interface is provided.
 */
@Stateless(name = "UserManager")
public class UserManagerImpl implements UserManager {

	@PersistenceContext(unitName = "CommunityBoard_data",  type=PersistenceContextType.TRANSACTION, properties = {
			@PersistenceProperty(name="javax.persistence.provider", 
					             value="oracle.toplink.essentials.ejb.cmp3.EntityManagerFactoryProvider")
	}) 		
	private EntityManager em;

    /**
     * Default constructor. 
     */
    public UserManagerImpl() {
    }

    /**
     * {@inheritDoc}}
     */ 
    @Override
    public User findUser (String nickname) {
    	CriteriaBuilder cb = em.getCriteriaBuilder();
    	CriteriaQuery<User> cq = cb.createQuery(User.class);
    	Root<User> rt = cq.from(User.class);
    	cq.where(cb.equal(rt.get("nickname"),nickname));
    	TypedQuery<User> query = em.createQuery(cq);
    	return query.getSingleResult();

    }

    /**
     * {@inheritDoc}}
     */
    @Override
    public User readUser(int userId) {
        return em.find(User.class, userId);
    }
    
    /**
     * {@inheritDoc}}
     */ 
    @Override
    public List<User> listUsers () {
        CriteriaBuilder cb = em.getCriteriaBuilder();
        CriteriaQuery<User> cq = cb.createQuery(User.class);
        TypedQuery<User> query = em.createQuery(cq);
        return query.getResultList();

    }

    /**
     * {@inheritDoc}}
     */
    @Override
    public void createUser(User newUser) {
        em.persist(newUser); 
    }

    /**
     * {@inheritDoc}}
     */
    @Override
    public void deleteUser(User user) {
        // unfortunately user might be detached
        em.remove(readUser(user.getId()));        
    }

    /**
     * {@inheritDoc}}
     */
    @Override
    public void updateUser(User user) {
        em.merge(user);
    }
    
}
