// ============================================================================
//
// Copyright (c) 2010, heig-vd.ch, niceideas.ch - Jerome Kehrli
//
// You may distribute this code under the terms of the GNU LGPL license
// (http://www.gnu.org/licenses/lgpl.html). [^]
//
// ============================================================================


package ch.niceideas.communityBoard.service;

import java.util.List;

import javax.ejb.Local;

import ch.niceideas.communityBoard.data.Forum;
import ch.niceideas.communityBoard.data.Note;
import ch.niceideas.communityBoard.data.Rating;
import ch.niceideas.communityBoard.data.User;

/**
 * Business Interface for LoginManager
 */
@Local
public interface ForumService {
	
    /**
     * List all forums available in the database
     * 
     * @return a list containing every forum
     * @throws ForumException in case anything goes wrong
     */
	List<Forum> listForums () throws ForumException;
	
	/**
     * Read the forum corresponding to the provided ID.
     * 
     * @param forumId the ID of the forum to read.
     * @return the corresponding forum
     * @throws ForumException in case anything goes wrong
     */
	Forum readForum (int forumId) throws ForumException;
	
	/**
     * List all notes belonging to the forum identified by the ID given as
     * argument
     * 
     * @param forumId the ID of the forum whose notes should be retrieved.
     * @return the corresponding list of notes
     * @throws ForumException in case anything goes wrong
     */
	List<Note> listNotes(int forumId) throws ForumException;

	/**
     * Read the note corresponding to the provided ID.
     * 
     * @param noteId the ID of the note to read.
     * @return the corresponding note
     * @throws ForumException in case anything goes wrong
     */
	Note readNote (int noteId) throws ForumException;

	/**
     * Insert the forum given as argument in the database.
     * 
     * @param newForum the new forum to insert in DB.
     * @throws ForumException in case anything goes wrong
     */
	void createForum(Forum newForum) throws ForumException;

	/**
     * Update the forum given as argument in the database. 
     * 
     * @param forum the forum to be updated in DB
     * @throws ForumException in case anything goes wrong
     */
	void updateForum(Forum forum) throws ForumException;

	/**
     * Delete the forum given as argument from the database.
     * 
     * @param forum the forum to be deleted
     * @throws ForumException in case anything goes wrong
     */
	void deleteForum(Forum forum) throws ForumException;

	/**
     * Read the user corresponding to the provided ID.
     * 
     * @param userId the ID of the user to read.
     * @return the corresponding user
     * @throws ForumException in case anything goes wrong
     */
    User readUser(int userId) throws ForumException;

    /**
     * List all users available in the database
     * 
     * @return a list containing every user
     * @throws ForumException in case anything goes wrong
     */  
    List<User> listUsers () throws ForumException;

    /**
     * Insert the user given as argument in the database.
     * 
     * @param newUser the new user to insert in DB.
     * @throws ForumException in case anything goes wrong
     */
    void createUser(User newUser) throws ForumException;

    /**
     * Update the user given as argument in the database. 
     * 
     * @param user the user to be updated in DB
     * @throws ForumException in case anything goes wrong
     */
    void updateUser(User user) throws ForumException;

    /**
     * Delete the user given as argument from the database.
     * 
     * @param user the user to be deleted
     * @throws ForumException in case anything goes wrong
     */
    void deleteUser(User user) throws ForumException;
    
    /**
     * Insert the note given as argument in the database.
     * 
     * @param newNote the new note to insert in DB.
     * @throws ForumException in case anything goes wrong
     */
    void createNote(Note newNote) throws ForumException;

    /**
     * Update the note given as argument in the database. 
     * 
     * @param note the note to be updated in DB
     * @throws ForumException in case anything goes wrong
     */
    void updateNote(Note note) throws ForumException;

    /**
     * Delete the note given as argument from the database.
     * 
     * @param note the note to be deleted
     * @throws ForumException in case anything goes wrong
     */
    void deleteNote(Note note) throws ForumException;
    
    /**
     * Insert the rating given as argument in the database.
     * 
     * @param newRating the new rating to insert in DB.
     * @throws ForumException in case anything goes wrong
     */
    void createRating(Rating newRating) throws ForumException;

    /**
     * Update the rating given as argument in the database. 
     * 
     * @param rating the rating to be updated in DB
     * @throws ForumException in case anything goes wrong
     */
    void updateRating(Rating rating) throws ForumException;

    /**
     * Delete the rating given as argument from the database.
     * 
     * @param rating the rating to be deleted
     * @throws ForumException in case anything goes wrong
     */
    void deleteRating(Rating rating) throws ForumException;

    /**
     * Read the rating corresponding to the provided ID.
     * 
     * @param ratingId the ID of the rating to read.
     * @return the corresponding rating
     * @throws ForumException in case anything goes wrong
     */
    Rating readRating(int ratingId) throws ForumException;
}
