// ============================================================================
//
// Copyright (c) 2010, heig-vd.ch, niceideas.ch - Jerome Kehrli
//
// You may distribute this code under the terms of the GNU LGPL license
// (http://www.gnu.org/licenses/lgpl.html). [^]
//
// ============================================================================


package ch.niceideas.communityBoard.service;

import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.ejb.EJB;
import javax.ejb.Stateless;
import javax.ejb.TransactionAttribute;
import javax.ejb.TransactionAttributeType;

import ch.niceideas.communityBoard.data.Forum;
import ch.niceideas.communityBoard.data.Note;
import ch.niceideas.communityBoard.data.Rating;
import ch.niceideas.communityBoard.data.User;
import ch.niceideas.communityBoard.manager.ForumManager;
import ch.niceideas.communityBoard.manager.NoteManager;
import ch.niceideas.communityBoard.manager.RatingManager;
import ch.niceideas.communityBoard.manager.UserManager;

/**
 * Session Bean implementation class ForumService.
 * <b />
 * 
 * This is the actual EJB implementation. It provides implementations for the 
 * business methods defined in the interface. The implementation is neither 
 * exposed not available to the outside world. Clients are meant to use the EJB
 * interface. In our case, only the @Local interface is provided.
 */
@Stateless(name = "ForumService")
public class ForumServiceImpl implements ForumService {

	private static final Logger logger = Logger.getLogger(ForumServiceImpl.class.getName());
	
	@EJB(name="ForumManager")
	private ForumManager forumManager;
	
	@EJB(name="NoteManager")
	private NoteManager noteManager;
	
	@EJB(name="UserManager")
    private UserManager userManager;
    
    @EJB(name="RatingManager")
    private RatingManager ratingManager;
	
    /**
     * Default constructor. 
     */
    public ForumServiceImpl() {
        // TODO Auto-generated constructor stub
    }

    /**
     * {@InheritDoc}
     */
	@Override
	public List<Forum> listForums() throws ForumException {
		try {
			return forumManager.listForums();
		} catch (Exception e) {
			logger.log(Level.SEVERE, e.getMessage(), e);
			throw new ForumException (e);
		}
	}        
	
	/**
     * {@InheritDoc}
     */
	@Override
	public Forum readForum (int forumId) throws ForumException {
		try {
			return forumManager.readForum(forumId);
		} catch (Exception e) {
			logger.log(Level.SEVERE, e.getMessage(), e);
			throw new ForumException (e);
		}
	}
	
    /**
     * {@InheritDoc}
     */
	@Override
	public List<Note> listNotes(int forumId) throws ForumException {
		try {
			return noteManager.listNotes(forumId);
		} catch (Exception e) {
			logger.log(Level.SEVERE, e.getMessage(), e);
			throw new ForumException (e);
		}
	}

	/**
     * {@InheritDoc}
     */
	@Override
	public Note readNote (int noteId) throws ForumException {
		try {
			return noteManager.readNote(noteId);
		} catch (Exception e) {
			logger.log(Level.SEVERE, e.getMessage(), e);
			throw new ForumException (e);
		}
	}

	/**
     * {@InheritDoc}
     */
	@Override
	@TransactionAttribute(TransactionAttributeType.REQUIRED)
	public void createForum(Forum newForum) throws ForumException {
		try {
			forumManager.createForum(newForum);
		} catch (Exception e) {
			logger.log(Level.SEVERE, e.getMessage(), e);
			throw new ForumException (e);
		}
	}

	/**
     * {@InheritDoc}
     */
	@Override
	@TransactionAttribute(TransactionAttributeType.REQUIRED)
	public void deleteForum(Forum forum) throws ForumException {
		try {
			forumManager.deleteForum(forum);
		} catch (Exception e) {
			logger.log(Level.SEVERE, e.getMessage(), e);
			throw new ForumException (e);
		}
	}

	/**
     * {@InheritDoc}
     */
	@Override
	@TransactionAttribute(TransactionAttributeType.REQUIRED)
	public void updateForum(Forum forum) throws ForumException {
		try {
			forumManager.updateForum(forum);
		} catch (Exception e) {
			logger.log(Level.SEVERE, e.getMessage(), e);
			throw new ForumException (e);
		}
	}

	/**
     * {@InheritDoc}
     */
    @Override
    @TransactionAttribute(TransactionAttributeType.REQUIRED)
    public void createNote(Note newNote) throws ForumException {
        try {
            noteManager.createNote(newNote);
        } catch (Exception e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
            throw new ForumException (e);
        }
    }

    /**
     * {@InheritDoc}
     */
    @Override
    @TransactionAttribute(TransactionAttributeType.REQUIRED)
    public void deleteNote(Note note) throws ForumException {
        try {
            noteManager.deleteNote(note);
        } catch (Exception e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
            throw new ForumException (e);
        }
    }

    /**
     * {@InheritDoc}
     */
    @Override
    public User readUser(int userId) throws ForumException {
        try {
            return userManager.readUser(userId);
        } catch (Exception e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
            throw new ForumException (e);
        }
    }

    /**
     * {@InheritDoc}
     */
    @Override
    public List<User> listUsers() throws ForumException {
        try {
            return userManager.listUsers();
        } catch (Exception e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
            throw new ForumException (e);
        }
    }       

    /**
     * {@InheritDoc}
     */
    @Override
    @TransactionAttribute(TransactionAttributeType.REQUIRED)
    public void createUser(User newUser) throws ForumException {
        try {
            userManager.createUser(newUser);
        } catch (Exception e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
            throw new ForumException (e);
        }
    }

    /**
     * {@InheritDoc}
     */
    @Override
    @TransactionAttribute(TransactionAttributeType.REQUIRED)
    public void deleteUser(User user) throws ForumException {
        try {
            userManager.deleteUser(user);
        } catch (Exception e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
            throw new ForumException (e);
        }
    }

    /**
     * {@InheritDoc}
     */
    @Override
    @TransactionAttribute(TransactionAttributeType.REQUIRED)
    public void updateUser(User user) throws ForumException {
        try {
            userManager.updateUser(user);
        } catch (Exception e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
            throw new ForumException (e);
        }
    }
    
    /**
     * {@InheritDoc}
     */
    @Override
    @TransactionAttribute(TransactionAttributeType.REQUIRED)
    public void updateNote(Note note) throws ForumException {
        try {
            noteManager.updateNote(note);
            note.getUser().refreshNote(note);
            note.getForum().refreshNote(note);
        } catch (Exception e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
            throw new ForumException (e);
        }        
    }
    
    /**
     * {@InheritDoc}
     */
    @Override
    @TransactionAttribute(TransactionAttributeType.REQUIRED)
    public void createRating(Rating newRating) throws ForumException {
        try {
            ratingManager.createRating(newRating);
        } catch (Exception e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
            throw new ForumException (e);
        }
    }

    /**
     * {@InheritDoc}
     */
    @Override
    @TransactionAttribute(TransactionAttributeType.REQUIRED)
    public void deleteRating(Rating rating) throws ForumException {
        try {
            ratingManager.deleteRating(rating);
        } catch (Exception e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
            throw new ForumException (e);
        }
    }
    
    /**
     * {@InheritDoc}
     */
    @Override
    @TransactionAttribute(TransactionAttributeType.REQUIRED)
    public void updateRating(Rating rating) throws ForumException {
        try {
            ratingManager.updateRating(rating);
            rating.getNote().refreshRating(rating);            
        } catch (Exception e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
            throw new ForumException (e);
        }                
    }

    /**
     * {@InheritDoc}
     */       
    @Override
    public Rating readRating(int ratingId) throws ForumException {
        try {
            return ratingManager.readRating(ratingId);
        } catch (Exception e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
            throw new ForumException (e);
        }
    }
}
