// ============================================================================
//
// Copyright (c) 2010, heig-vd.ch, niceideas.ch - Jerome Kehrli
//
// You may distribute this code under the terms of the GNU LGPL license
// (http://www.gnu.org/licenses/lgpl.html). [^]
//
// ============================================================================

package ch.niceideas.communityBoard.service;

import java.util.logging.Level;
import java.util.logging.Logger;

import javax.ejb.EJB;
import javax.ejb.Stateless;

import ch.niceideas.communityBoard.data.User;
import ch.niceideas.communityBoard.manager.UserManager;

/**
 * Session Bean implementation class LoginService.
 * <b />
 * 
 * This is the actual EJB implementation. It provides implementations for the 
 * business methods defined in the interface. The implementation is neither 
 * exposed not available to the outside world. Clients are meant to use the EJB
 * interface. In our case, only the @Local interface is provided.
 */
@Stateless(name = "LoginService")
public class LoginServiceImpl implements LoginService {

	private static final Logger logger = Logger.getLogger(LoginServiceImpl.class.getName());
	
	@EJB(name="UserManager")
	private UserManager userManager;
	
    /**
     * Default constructor. 
     */
    public LoginServiceImpl() {
        // TODO Auto-generated constructor stub
    }
    
    /**
     * {@InheritDoc}
     */
    @Override
    public User login (String nickname, String password) throws LoginException {
    	User user = null;
    	try {
	    	user = userManager.findUser(nickname);
	    	if (user == null) {
	    		logger.severe("No user found with nickname " + nickname);
	    		throw new LoginException ("No user found with nickname " + nickname);
	    	}
	    	if (!user.getPassword().equals(password)) {
	    		logger.severe("Wrong password givem for user with nickname " + nickname);
	    		throw new LoginException ("Wrong password givem for user with nickname " + nickname);
	    	}
    	} catch (RuntimeException e) {
    		logger.log(Level.SEVERE, e.getMessage(), e);
    	}
    	
    	return user;
    }

}
